MethodChannelDeviceIdAll class
An implementation of DeviceIdAllPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- DeviceIdAllPlatform
- MethodChannelDeviceIdAll
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAllDeviceIdentifiers(
) → Future< DeviceIdentifierInfo> -
override
-
getAndroidGaid(
) → Future< String?> -
override
-
getAndroidId(
) → Future< String?> -
override
-
getAndroidImei(
) → Future< String?> -
override
-
getAndroidOaid(
) → Future< String?> -
override
-
getAppInstanceUuid(
) → Future< String?> -
override
-
getBestEffortDeviceId(
) → Future< String?> -
override
-
getIosIdfa(
) → Future< String?> -
override
-
getIosTrackingAuthorizationStatus(
) → Future< IosTrackingAuthorizationStatus> -
override
-
getIosUdid(
) → Future< String?> -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preloadAndroidOaid(
) → Future< bool> -
override
-
requestIosTrackingAuthorization(
) → Future< IosTrackingAuthorizationStatus> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited