DeviceIdAllPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- DeviceIdAllPlatform
- Implementers
Constructors
- DeviceIdAllPlatform()
- Constructs a DeviceIdAllPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAllDeviceIdentifiers(
) → Future< DeviceIdentifierInfo> -
getAndroidGaid(
) → Future< String?> -
getAndroidId(
) → Future< String?> -
getAndroidImei(
) → Future< String?> -
getAndroidOaid(
) → Future< String?> -
getAppInstanceUuid(
) → Future< String?> -
getBestEffortDeviceId(
) → Future< String?> -
getIosIdfa(
) → Future< String?> -
getIosTrackingAuthorizationStatus(
) → Future< IosTrackingAuthorizationStatus> -
getIosUdid(
) → Future< String?> -
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preloadAndroidOaid(
) → Future< bool> -
requestIosTrackingAuthorization(
) → Future< IosTrackingAuthorizationStatus> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ DeviceIdAllPlatform
-
The default instance of DeviceIdAllPlatform to use.
getter/setter pair