IosTrackingAuthorizationStatus enum
iOS App Tracking Transparency 授权状态。
只有 IDFA 受这个状态影响;Android 平台固定返回 notSupported。
Values
- notSupported → const IosTrackingAuthorizationStatus
- notDetermined → const IosTrackingAuthorizationStatus
- restricted → const IosTrackingAuthorizationStatus
- denied → const IosTrackingAuthorizationStatus
- unknown → const IosTrackingAuthorizationStatus
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
-
values
→ const List<
IosTrackingAuthorizationStatus> - A constant List of the values in this enum, in order of their declaration.